import { agent } from '@/agent/agent.ts';
import { ai } from '../ai.ts';
import { getJsonFromString } from './content.ts';
export type Category = {
  category: string;
  description: string;
};
export const categoryList: Category[] = [
  {
    category: 'daily_poetry',
    description: '获取一篇今日诗词',
  },
  {
    category: 'irony',
    description: '反讽一下',
  },
  {
    category: 'random_beautiful_text',
    description: '随机生成一段优美的文字',
  },
  {
    category: 'random_joke',
    description: '随机生成一个笑话',
  },
  {
    category: '',
    description: '教教我，怎么做'
  },
  {
    category: 'default',
    description: '默认分类，无法识别的请求',
  },
];
agent
  .route({
    path: 'analyze',
    key: 'category',
    description: '分析文本内容，判断文本的请求分类。比如，1. 获取一篇今日诗词。2. 反讽一下 3. 随机生成一段优美的文字。',
  })
  .define(async (ctx) => {
    const text = ctx.query?.text || '';

    const prompt = `
请分析以下文本内容，判断文本的请求分类，并返回一个JSON对象。

识别的分类包括：
${categoryList.map((item) => `- ${item.category}: ${item.description}`).join('\n')}

返回内容示例：
\`\`\`json
{
  "category": "daily_poetry"
}
\`\`\`
<context>
${text}
</context>
`;
    const res = await ai
      .chat(
        [
          {
            role: 'user',
            content: prompt,
          },
        ],
        {
          enable_thinking: false,
        },
      )
      .catch((error) => {
        ctx.throw(500, 'AI 服务错误: ' + error.status);
        return error;
      });
    const content = res.choices?.[0]?.message?.content || '';
    const jsonResponse = getJsonFromString(content);
    const category = jsonResponse?.category || 'default';
    ctx.body = { category };
  })
  .addTo(agent);
