import { agent } from '@/agent/agent.ts';
import { ai } from '../ai.ts';
import { logger } from '@/agent/logger.ts';
export const getJsonFromString = (str: string) => {
  // 尝试从字符串中提取JSON对象
  try {
    const jsonMatch = str.match(/```json\s*([\s\S]*?)\s*```/);
    if (jsonMatch && jsonMatch[1]) {
      return JSON.parse(jsonMatch[1]);
    }
  } catch (error) {
    console.error('Error parsing JSON from string:', error);
  }
  return null;
};
agent
  .route({
    path: 'analyze',
    key: 'content',
    description: '分析文本内容,意图分析，判断是否需要获取上下文包函小红书的图片，视频，文本。',
  })
  .define(async (ctx) => {
    const text = ctx.query?.text || '';

    let result = {
      image: false,
      video: false,
      text: false,
      comment: false,
    };

    const prompt = `
请分析<context>包函的内容，判断是否需要包含小红书的图片、视频或文本信息，返回一个JSON对象，包含三个布尔值：image（是否包含图片）、video（是否包含视频）、text（是否包含小红书文本），comment（是否是评论信息）。
如果文本中提到图片或视频，请返回true，否则返回false。

文本示例：
1. "解答一下这个笔记。" , text为true
2. "分析一下这个图片。", image为true
3. "这个视频介绍的是什么。", video为true
4. "评价一下这个评论。", comment为true

返回内容示例：
\`\`\`json
{
  "image": true,
  "video": false,
  "text": true,
  "comment": false
}
\`\`\`
分析的文本的内容是:
<context>
${text}
</context>
    `;
    const now = Date.now();
    console.log('start');
    const res = await ai
      .chat(
        [
          {
            role: 'user',
            content: prompt,
          },
        ],
        {
          // @ts-ignore
          enable_thinking: false,
        },
      )
      .catch((err) => {
        console.log('AI service error:', err.status);
        ctx.throw(500, 'AI service error: ' + err.status);
        return err;
      });

    console.log('end', Date.now() - now, 'ms');
    const ans = res.choices[0]?.message?.content || '';
    if (!ans) {
      logger.error('Empty response from AI:', res);
    }
    const json = getJsonFromString(ans);
    if (!json) {
      logger.error('Invalid JSON format in response:', ans);
      ctx.throw(400, 'Invalid JSON format in response');
    }
    result = {
      image: json.image || false,
      video: json.video || false,
      text: json.text || false,
      comment: json.comment || false,
    };
    ctx.body = result;
  })
  .addTo(agent);
