import { agent } from '@/agent/agent.ts';
import { ai } from '../ai.ts';
import { logger } from '@/agent/logger.ts';

const getTagContent = (text: string) => {
  const match = text.match(/<content>([\s\S]*?)<\/content>/);
  return match ? match[1].trim() : text;
};
agent
  .route({
    path: 'fix',
    key: 'xhs',
    description: '对小红书的提示词进行修正和优化',
  })
  .define(async (ctx) => {
    const text = ctx.query?.text || '';
    const now = Date.now();
    console.log('start');
    const res = await ai
      .chat(
        [
          {
            role: 'user',
            content: `
你是一个提示词优化的专家，请根据用户提供的提示词进行修正和优化，其中用户的提示词返回的要求如果没有或者不明确，请你修正为要求返回的文本在500字以内，如果有，保持原本的要求数字的文本。与此同时，要求内容是纯文本格式，不能是markdown模式，也不包含任何HTML标签或其他格式化内容。

只对提示词进行优化，并且不需要对内容进行分析或总结。并返回修改后的总的提示词内容。

示例1. 用户提示词
<content>总结笔记</content>
优化后的提示词
<content>请总结一下这个笔记，要求返回的内容是纯文本格式，字数不超过500字。</content>
示例2. 用户提示词
<content>分析一下这个图片</content>
优化后的提示词
<content>请分析一下这个图片，要求返回的内容是纯文本格式，字数不超过500字。</content>
示例3. 用户提示词
<content>分析一下这个笔记，300字内</content>
优化后的提示词
<content>请分析一下这个笔记，要求返回的内容是纯文本格式，字数不超过300字。</content>


用户的提示词是
<content>
${text}
</content>
`,
          },
        ],
        {
          // @ts-ignore
          enable_thinking: false,
        },
      )
      .catch((err) => {
        console.log('AI service error:', err.status);
        ctx.throw(500, 'AI service error: ' + err.status);
        return err;
      });

    console.log('end', Date.now() - now, 'ms');
    console.log('AI response:', res);
    const ans = res.choices[0]?.message?.content || '';
    if (!ans) {
      logger.error('Empty response from AI:', res);
    }
    ctx.body = getTagContent(ans);
  })
  .addTo(agent);
