import { agent } from '../agent.ts';
import { ai } from '../ai.ts';

agent
  .route({
    path: 'tools',
    key: 'summarize-note',
  })
  .define(async (ctx: any) => {
    const text = ctx?.query?.text || '';
    const note = ctx?.query?.note || '';
    if (!text) {
      ctx.throw('请提供要总结的笔记内容');
    }

    const prompt = `
请根据以下内容生成一段总结：
要求
0. 如果没有必要总结，直接返回 "当前内容不需要总结"。
1. 总结内容要简洁明了，突出重点。
2. 使用口语化的表达方式，易于理解。
3. 总结内容要有逻辑性，能够清晰地传达信息。
4. 如果有必要，可以使用一些比喻或形象的表达方式来增强总结的效果。
5. 总结内容要与原文内容相关，不能脱离主题。
6. 250字以内。
7. 不要包含除开总结内容以外的其他内容。
8. 其他要求：
${text ? text : '无'}

当前的笔记内容是：
${note}
`;

    const res = await ai.chat(
      [
        {
          role: 'user',
          content: prompt,
        },
      ],
      {
        // @ts-ignore
        enable_thinking: false,
      },
    );
    const pickRes = res.choices[0]?.message?.content || '';
    if (!pickRes) {
      ctx.throw('AI 没有返回任何内容，请稍后再试');
    }
    // 返回总结内容
    ctx.body = pickRes.trim();
  })
  .addTo(agent);
