import { agent } from '@/agent/index.ts';
import { taskApp, queue, xhsApp, xhsServices } from '../task.ts';
import { random, omit } from 'lodash-es';
import util from 'node:util';

export const sleep = (ms: number) => {
  return new Promise((resolve) => setTimeout(resolve, ms));
};

taskApp
  .route({
    path: 'task',
    key: 'getUnread',
    description: '获取未读提及消息',
  })
  .define(async (ctx) => {
    const res = await xhsApp.call({
      path: 'mention',
      key: 'getUnread',
    });
    if (res.code === 200) {
      const data = res.body;
      const unread_count = data.unread_count;
      const likes = data.likes;
      const unread = unread_count - likes;
      if (unread > 0) {
        queue.add(
          'mention',
          {
            path: 'task',
            key: 'getMention',
            payload: {
              unread_count: unread,
            },
          },
          {
            attempts: 1,
            delay: 0,
            removeOnComplete: true,
            removeOnFail: {
              age: 24 * 3600, // keep up to 24 hours
            },
          },
        );
      }
      ctx.body = {
        job: unread,
      };
    }
  })
  .addTo(taskApp);

taskApp
  .route({
    path: 'task',
    key: 'getMention',
    description: '获取提及消息',
  })
  .define(async (ctx) => {
    const { unread_count } = ctx.query;
    if (unread_count > 0) {
      const mentionRes = await xhsApp.call({
        path: 'mention',
        key: 'getMention',
        payload: {
          num: unread_count,
        },
      });
      if (mentionRes.code === 200) {
        let data = mentionRes.body || [];
        // data = data.map((item) => omit(item, 'mention'));
        for (let i = 0; i < data.length; i++) {
          const item = data[i];
          queue.add(
            'mention-ai',
            {
              path: 'task',
              key: 'ai',
              payload: {
                data: item,
              },
            },
            {
              attempts: 3,
              delay: 0,
              removeOnComplete: true,
              removeOnFail: {
                age: 24 * 3600, // keep up to 24 hours
              },
            },
          );
          await sleep(200);
        }
      }
      const postRead = await xhsApp.call({
        path: 'mention',
        key: 'postRead',
      });
    }
    ctx.body = {
      job: unread_count,
    };
  })
  .addTo(taskApp);

taskApp
  .route({
    path: 'task',
    key: 'ai',
  })
  .define(async (ctx) => {
    const data = ctx.query.data; // 为提及的相关信息
    const note_id = data.note_id;
    const note_userid = data.note_userid;
    const note_username = data.note_username;

    // 检测是这个用户的username的笔记，如果是的话，需要有at的用户信息才继续。
    const isOwner = xhsServices.isOwner({ username: note_username, userid: note_userid });
    const isReplayAi = xhsServices.isReplayAi(data);
    const xsec_token = data.xsec_token;
    console.log(data);
    const comment_id = data.comment.comment_id;
    let content: string = data.comment?.content || 'test';
    const postData = {
      note_id,
      content,
      comment_id,
    };
    if (isOwner) {
      // 如果是自己的笔记，且笔记不包含 @信息 则不需要AI回复,
      const hasAt = content.includes('@' + note_username) || content.includes('@' + note_userid);
      if (!hasAt) {
        // console.log('不需要AI回复自己的笔记', note_username, note_id, content);
        return;
      }
    }

    content = content.replace('@' + note_username, '');
    const sliceContentCmd = content.slice(0, 20);
    let note = '';
    let hasNote = false;
    if (sliceContentCmd.includes('笔记') || sliceContentCmd.includes('总结')) {
      const res = await xhsApp.call({ path: 'note', key: 'getNote', payload: { node_id: note_id, xsec_token } });
      if (res.code === 200) {
        note = res.body?.desc || '';
        hasNote = note ? true : false;
      }
    }
    if (isReplayAi) {
      // 如果是对AI回复的评论，则不需要再回复
      console.log('不需要AI回复AI的评论', note_username, note_id, content);
      return;
    }
    const resAgent = await agent.call({
      path: 'xhs',
      payload: {
        text: content,
        note,
        hasNote,
      },
    });
    let responseText = '';
    let errorText = '';
    if (resAgent.code !== 200) {
      errorText = '【调用错误】';
      responseText = `${resAgent.message}`;
    } else {
      responseText = resAgent.body;
    }
    postData.content = responseText;
    const res = await xhsApp.call({
      path: 'mention',
      key: 'addComment',
      payload: postData,
    });
    console.log('addComment', postData, 'res', res.body);
  })
  .addTo(taskApp);
