// https://edith.xiaohongshu.com/api/sns/web/unread_count

import { QueryRouterServer } from '@kevisual/router';
import { redis } from '@/modules/redis.ts';
import { Queue } from 'bullmq';
import { app as xhsApp, xhsServices as xhs, xhsRootClient, XhsServices } from '@kevisual/xhs/index.ts';
import { nanoid } from 'nanoid';
export const XHS_GET_UNREAD = 'unread_count';
export const XHS_QUEUE_NAME = 'XHS_QUEUE';
import { config, isDev } from '../modules/config.ts';

const server: XhsServices = xhs;
server.setCookie(config.XHS_ROOT_COOKIE || '');
server.setUserInfo({
  userid: config.XHS_USER_ID || '',
  username: config.XHS_USER_NAME || '',
});
if (isDev) {
  server.setSignConfig({
    signUrl: 'http://localhost:5006/sign',
  });
}
console.log('XHS_USER_INFO', config.XHS_USER_ID, config.XHS_USER_NAME, 'XHS_ROOT_COOKIE', config.XHS_ROOT_COOKIE);
console.log('XHS_SIGN_URL', server.getSignConfig().signUrl);
export const taskApp = new QueryRouterServer();
export { xhsApp };
export const xhsServices = server;

export const queue = new Queue(XHS_QUEUE_NAME, {
  connection: redis,
});

export const addUnreadTask = async (nextTime = 0) => {
  const id = 'unread';
  const job = await queue.add(
    'unread',
    {
      path: 'task',
      key: 'getUnread',
    },
    {
      delay: nextTime,
      removeOnComplete: true,
      attempts: 1,
      removeOnFail: {
        age: 24 * 3600, // keep up to 24 hours
      },
      jobId: id,
    },
  );
  return {
    id,
    job,
  };
};
